===========
ce_detector
===========


.. image:: https://img.shields.io/pypi/v/ce_detector.svg
   :target: https://pypi.python.org/pypi/ce_detector

.. image:: https://travis-ci.com/cauliyang/ce_detector.svg?token=ny2TT3zEDqv1DqKs8ocf&branch=master
    :target: https://travis-ci.com/cauliyang/ce_detector

.. image:: https://readthedocs.org/projects/ce-detector/badge/?version=latest
   :target: https://ce-detector.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status



A program used to detect Cryptic Exon


* Free software: MIT license
* Documentation: https://ce-detector.readthedocs.io.


Features
--------

* Detect Junction Reads
* Annotate Junction Reads
* Detect Cryptic Exon

Installation
------------

Using pip::

   $ pip install ce-detector

Using conda::

   $ conda install ce-detector

Usage example
-------------

_For more examples and usage, please refer to Document_

Development setup
-----------------


Describe how to install all development dependencies and how to run an automated test-suite of some kind. Potentially do this for multiple platforms.::

   $ pip install -r requirement_dev.txt



Contributing
------------

1. Fork it (<https://github.com/cauliyang/ce_detector/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request



Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _Document:  https://ce-detector.readthedocs.io
